@@ -14,38 +14,47 @@ def table_renderer(widget, data):
     }
     return data.tag('table', data.rendered, **attrs)
 
+
+factory.register(
+    'table',
+    extractors=factory.extractors('compound'),
+    edit_renderers=factory.edit_renderers('compound') + [table_renderer],
+    display_renderers=factory.display_renderers('compound') + [table_renderer])
+
 factory.doc['widget']['table'] = """\
 ``<table>`` compound widget for table creation.
 """
 
-factory.register('table',
-                 factory.extractors('compound'),
-                 factory.renderers('compound') + [table_renderer])
-
 
 def thead_renderer(widget, data):
     return data.tag('thead', data.rendered)
 
+
+factory.register(
+    'thead',
+    extractors=factory.extractors('compound'),
+    edit_renderers=factory.edit_renderers('compound') + [thead_renderer],
+    display_renderers=factory.display_renderers('compound') + [thead_renderer])
+
 factory.doc['widget']['thead'] = """\
 ``<thead>`` compound widget for table creation.
 """
 
-factory.register('thead',
-                 factory.extractors('compound'),
-                 factory.renderers('compound') + [thead_renderer])
-
 
 def tbody_renderer(widget, data):
     return data.tag('tbody', data.rendered)
 
+
+factory.register(
+    'tbody',
+    extractors=factory.extractors('compound'),
+    edit_renderers=factory.edit_renderers('compound') + [tbody_renderer],
+    display_renderers=factory.display_renderers('compound') + [tbody_renderer])
+
 factory.doc['widget']['tbody'] = """\
 ``<tbody>`` compound widget for table creation.
 """
 
-factory.register('tbody',
-                 factory.extractors('compound'),
-                 factory.renderers('compound') + [tbody_renderer])
-
 
 @managedprops('id', *css_managed_props)
 def tr_renderer(widget, data):
@@ -55,14 +64,17 @@ def tr_renderer(widget, data):
     }
     return data.tag('tr', data.rendered, **attrs)
 
+
+factory.register(
+    'tr',
+    extractors=factory.extractors('compound'),
+    edit_renderers=factory.edit_renderers('compound') + [tr_renderer],
+    display_renderers=factory.display_renderers('compound') + [tr_renderer])
+
 factory.doc['widget']['tr'] = """\
 ``<tr>`` compound widget for table creation.
 """
 
-factory.register('tr',
-                 factory.extractors('compound'),
-                 factory.renderers('compound') + [tr_renderer])
-
 
 @managedprops('id', 'rowspan', 'colspan', 'label', *css_managed_props)
 def th_renderer(widget, data):
@@ -77,14 +89,16 @@ def th_renderer(widget, data):
         contents = data.rendered
     return data.tag('th', contents, **attrs)
 
+
+factory.register(
+    'th',
+    edit_renderers=[th_renderer],
+    display_renderers=[th_renderer])
+
 factory.doc['widget']['th'] = """\
 ``<th>`` compound widget for table creation.
 """
 
-factory.register('th',
-                 [],
-                 [th_renderer])
-
 
 @managedprops('id', 'rowspan', 'colspan', *css_managed_props)
 def td_renderer(widget, data):
@@ -96,10 +110,12 @@ def td_renderer(widget, data):
     }
     return data.tag('td', data.rendered, **attrs)
 
+
+factory.register(
+    'td',
+    edit_renderers=[td_renderer],
+    display_renderers=[td_renderer])
+
 factory.doc['widget']['td'] = """\
 ``<td>`` compound widget for table creation.
-"""
-
-factory.register('td',
-                 [],
-                 [td_renderer])
\ No newline at end of file
+"""
\ No newline at end of file
