@@ -9,13 +9,12 @@ optionflags = doctest.NORMALIZE_WHITESPACE | \
               doctest.REPORT_ONLY_FIRST_FAILURE
 
 TESTFILES = [
-    'utils.txt',
-    'base.txt',
-    'common.txt',
-    'compound.txt',
-    'controller.txt',
-    'mode.txt',
-    'table.txt',
+    'utils.rst',
+    'base.rst',
+    'common.rst',
+    'compound.rst',
+    'controller.rst',
+    'table.rst',
 ]
 
 
@@ -40,4 +39,4 @@ def test_suite():
     ])
 
 if __name__ == '__main__':                                   #pragma NO COVERAGE
-    unittest.main(defaultTest='test_suite')                  #pragma NO COVERAGE
\ No newline at end of file
+    unittest.main(defaultTest='test_suite')                  #pragma NO COVERAGE
